==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/CodeBuild/ListCuratedEnvironmentImages.pm <==

package Paws::CodeBuild::ListCuratedEnvironmentImages;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListCuratedEnvironmentImages');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeBuild::ListCuratedEnvironmentImagesOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeBuild::ListCuratedEnvironmentImages - Arguments for method ListCuratedEnvironmentImages on Paws::CodeBuild

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListCuratedEnvironmentImages on the 
AWS CodeBuild service. Use the attributes of this class
as arguments to method ListCuratedEnvironmentImages.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListCuratedEnvironmentImages.

As an example:

  $service_obj->ListCuratedEnvironmentImages(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListCuratedEnvironmentImages in L<Paws::CodeBuild>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/CodeBuild/ListCuratedEnvironmentImages.pm <==

package Paws::CodeBuild::ListCuratedEnvironmentImages;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListCuratedEnvironmentImages');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeBuild::ListCuratedEnvironmentImagesOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeBuild::ListCuratedEnvironmentImages - Arguments for method ListCuratedEnvironmentImages on L<Paws::CodeBuild>

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListCuratedEnvironmentImages on the
L<AWS CodeBuild|Paws::CodeBuild> service. Use the attributes of this class
as arguments to method ListCuratedEnvironmentImages.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListCuratedEnvironmentImages.

=head1 SYNOPSIS

    my $codebuild = Paws->service('CodeBuild');
    my $ListCuratedEnvironmentImagesOutput =
      $codebuild->ListCuratedEnvironmentImages();

    # Results:
    my $Platforms = $ListCuratedEnvironmentImagesOutput->Platforms;

    # Returns a L<Paws::CodeBuild::ListCuratedEnvironmentImagesOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/codebuild/ListCuratedEnvironmentImages>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListCuratedEnvironmentImages in L<Paws::CodeBuild>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
